;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "simply-annotate" "20250703.2055"
  "Enhanced annotation system with threading."
  '((emacs "28.1"))
  :url "https://github.com/captainflasmr/simply-annotate"
  :commit "7fbeb4d76fd242ec0cdadca20857af5c43e2da5e"
  :revdesc "7fbeb4d76fd2"
  :keywords '("applications" "tools" "convenience")
  :authors '(("James Dyer" . "captainflasmr@gmail.com"))
  :maintainers '(("James Dyer" . "captainflasmr@gmail.com")))
